aboutsummaryrefslogtreecommitdiff
path: root/bdep/project.hxx
diff options
context:
space:
mode:
authorBoris Kolpackov <boris@codesynthesis.com>2018-03-12 11:17:21 +0200
committerBoris Kolpackov <boris@codesynthesis.com>2018-03-12 11:17:21 +0200
commit5dcbecfd8b83f516c067780214f06321f03d1cce (patch)
tree20dcd6d7c602c4fcc7432f46336086156c929067 /bdep/project.hxx
parent4d181c3aad97f8ee224666ce5c757036c5f610d5 (diff)
Initial sync implementation
Diffstat (limited to 'bdep/project.hxx')
-rw-r--r--bdep/project.hxx12
1 files changed, 9 insertions, 3 deletions
diff --git a/bdep/project.hxx b/bdep/project.hxx
index 2d0d3f1..16716ef 100644
--- a/bdep/project.hxx
+++ b/bdep/project.hxx
@@ -142,8 +142,12 @@ namespace bdep
// Given the project options (and CWD) locate the packages and their
// project. The result is an absolute and normalized project directory and a
// vector of relative (to the project directory) package locations (which
// will be empty if ignore_packages is true).
//
// Note that if the package directory is the same as project, then the
// package path will be empty (and not ./).
@@ -163,7 +167,9 @@ namespace bdep
};
project_packages
- find_project_packages (const project_options&, bool ignore_packages = false);
+ find_project_packages (const project_options&,
+ bool ignore_packages = false,
+ bool load_packages = true);
}
#endif // BDEP_PROJECT_HXX
@@ -142,8 +142,12 @@ namespace bdep
// Given the project options (and CWD) locate the packages and their
// project. The result is an absolute and normalized project directory and a
- // vector of relative (to the project directory) package locations (which
- // will be empty if ignore_packages is true).
+ // vector of relative (to the project directory) package locations.
+ //
+ // If ignore_packages is true then ignore packages in case the resulting
+ // vector will be empty. Otherwise, if load_packages is false, then don't
+ // load all the available packages from packages.manifest if none were
+ // found/specified.
//
// Note that if the package directory is the same as project, then the